Struct TimeoutFuture
pub struct TimeoutFuture { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
A future that resolves once a certain timeout is expired
Implementations
impl TimeoutFuture
impl TimeoutFuture
pub fn from_duration<Data>(
handle: &LoopHandle<'_, Data>,
duration: Duration,
) -> TimeoutFuture ⓘ
pub fn from_duration<Data>( handle: &LoopHandle<'_, Data>, duration: Duration, ) -> TimeoutFuture ⓘ
Create a future that resolves after a given duration
pub fn from_deadline<Data>(
handle: &LoopHandle<'_, Data>,
deadline: Instant,
) -> TimeoutFuture ⓘ
pub fn from_deadline<Data>( handle: &LoopHandle<'_, Data>, deadline: Instant, ) -> TimeoutFuture ⓘ
Create a future that resolves at a given instant